Exception: Roast::Cogs::Chat::MaxTokensExceededError

Inherits:
Roast::Cog::CogError show all
Defined in:
lib/roast/cogs/chat.rb

Overview

Raised when the LLM response hits the max token limit, indicating the output was truncated and should not be considered usable.