Exception: Roast::ControlFlow::FailCog

Inherits:
Base
  • Object
show all
Defined in:
lib/roast/control_flow.rb

Overview

Raised in a cog’s input block or execute method to terminate the cog and mark it as ‘failed’ without terminating the workflow. The workflow may abort anyway if the cog is configured to abort the workflow on failure.