Exception: Roast::ControlFlow::Next

Inherits:
Base
  • Object
show all
Defined in:
lib/roast/control_flow.rb

Overview

Raised in a cog’s input block or execute method to terminate the current loop iteration and start the next iteration immediately. The current cog will be marked as ‘skipped’, and every subsequent cog in the current iteration will not run. Any async cogs currently running in the current scope will be stopped.

If this exception is raised outside of a loop (e.g, via the ‘call` cog, or in the top-level executor), this exception will just terminate that executor as described above without starting a ’next’ iteration.