Class: Roast::ExecutionContext
- Inherits:
-
Object
- Object
- Roast::ExecutionContext
- Defined in:
- lib/roast/execution_context.rb
Overview
Context in which the execute blocks of a workflow definition are evaluated
Context in which the execute blocks of a workflow definition are evaluated