Class: Roast::SystemCogs::Map::Params

Inherits:
Roast::SystemCog::Params show all
Defined in:
lib/roast/system_cogs/map.rb

Overview

Parameters for the ‘map` cog

Instance Attribute Summary collapse

Attributes inherited from Roast::SystemCog::Params

#name

Instance Method Summary collapse

Methods inherited from Roast::SystemCog::Params

#anonymous?

Constructor Details

#initialize(name = nil, run:) ⇒ Params

Initialize parameters with the cog name and execution scope

: (?Symbol?, run: Symbol) -> void



105
106
107
108
# File 'lib/roast/system_cogs/map.rb', line 105

def initialize(name = nil, run:)
  super(name)
  @run = run
end

Instance Attribute Details

#runObject

The name of the execution scope to invoke for each item

: Symbol



100
101
102
# File 'lib/roast/system_cogs/map.rb', line 100

def run
  @run
end