Class: Roast::SystemCogs::Repeat::Params

Inherits:
Roast::SystemCog::Params show all
Defined in:
lib/roast/system_cogs/repeat.rb

Overview

Parameters for the ‘repeat` cog

Instance Attribute Summary collapse

Attributes inherited from Roast::SystemCog::Params

#name

Instance Method Summary collapse

Methods inherited from Roast::SystemCog::Params

#anonymous?

Constructor Details

#initialize(name = nil, run:) ⇒ Params

Initialize parameters with the cog name and execution scope

: (?Symbol?, run: Symbol) -> void



27
28
29
30
# File 'lib/roast/system_cogs/repeat.rb', line 27

def initialize(name = nil, run:)
  super(name)
  @run = run
end

Instance Attribute Details

#runObject

The name of the execution scope to invoke for each iteration

: Symbol



22
23
24
# File 'lib/roast/system_cogs/repeat.rb', line 22

def run
  @run
end