Class: Roast::SystemCogs::Map
- Inherits:
-
Roast::SystemCog
- Object
- Cog
- Roast::SystemCog
- Roast::SystemCogs::Map
- Defined in:
- lib/roast/system_cogs/map.rb
Overview
Map cog for executing a scope over a collection of items
Executes a named execution scope (defined with ‘execute(:name)`) for each item in a collection. Supports both serial and parallel execution modes. Each iteration receives the current item as its value and the iteration index.
Defined Under Namespace
Modules: InputContext, Manager Classes: Config, Input, MapIterationDidNotRunError, MapOutputAccessError, Output, Params
Instance Attribute Summary
Attributes inherited from Cog
Method Summary
Methods inherited from Roast::SystemCog
#execute, #initialize, params_class
Methods inherited from Cog
#anonymous?, config_class, #failed?, generate_fallback_name, #initialize, input_class, #run!, #skipped?, #started?, #stopped?, #succeeded?, #type, #wait
Constructor Details
This class inherits a constructor from Roast::SystemCog