Exception: Roast::SystemCogs::Map::MapIterationDidNotRunError
- Inherits:
-
MapOutputAccessError
- Object
- StandardError
- Error
- MapOutputAccessError
- Roast::SystemCogs::Map::MapIterationDidNotRunError
- Defined in:
- lib/roast/system_cogs/map.rb
Overview
Raised when attempting to access an iteration that did not run
This can occur when a ‘break!` is called during iteration, preventing subsequent iterations from executing.