Class: Roast::SystemCogs::Repeat
- Inherits:
-
Roast::SystemCog
- Object
- Cog
- Roast::SystemCog
- Roast::SystemCogs::Repeat
- Defined in:
- lib/roast/system_cogs/repeat.rb
Overview
Repeat cog for executing a scope multiple times in a loop
Executes a named execution scope (defined with ‘execute(:name)`) repeatedly until a `break!` is called. The output from each iteration becomes the input value for the next iteration, allowing for iterative transformations.
Defined Under Namespace
Modules: Manager Classes: Config, Input, Output, Params
Instance Attribute Summary
Attributes inherited from Cog
Method Summary
Methods inherited from Roast::SystemCog
#execute, #initialize, params_class
Methods inherited from Cog
#anonymous?, config_class, #failed?, generate_fallback_name, #initialize, input_class, #run!, #skipped?, #started?, #stopped?, #succeeded?, #type, #wait
Constructor Details
This class inherits a constructor from Roast::SystemCog